netapp_ontap.models.shelf_vendor API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_vendor`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfVendorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfVendor object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `manufacturer GET POST PATCH`

    Manufacturer name

    Example: XYZ

  `part_number GET POST PATCH`

    Part number

    Example: A92831142733

  `product GET POST PATCH`

    Product name

    Example: LS2246

  `serial_number GET POST PATCH`

    Serial number

    Example: 891234572210221